@@ -6,18 +6,18 @@ use strict;
 use warnings;
 
 use Carp;
+use PPI::Document;
 use PPIx::QuoteLike::Constant qw{ VARIABLE_RE };
 
 use base qw{ PPIx::QuoteLike::Token };
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 sub ppi {
     my ( $self ) = @_;
     ( my $content = $self->content() ) =~
 	s/ \A ( [\$\@] (?: \# \$? | \$* ) )
 	\{ ( @{[ VARIABLE_RE ]} ) \} \z /$1$2/smxo;
-    require PPI::Document;
     return PPI::Document->new( \$content, readonly => 1 )
 }
 
